@@ -30,14 +30,30 @@ static int64_t base_sys_ts = 0;
 static inline enum video_format convert_pixel_format(int f)
 {
 	switch (f) {
-	case AV_PIX_FMT_NONE:    return VIDEO_FORMAT_NONE;
-	case AV_PIX_FMT_YUV420P: return VIDEO_FORMAT_I420;
-	case AV_PIX_FMT_NV12:    return VIDEO_FORMAT_NV12;
-	case AV_PIX_FMT_YUYV422: return VIDEO_FORMAT_YUY2;
-	case AV_PIX_FMT_UYVY422: return VIDEO_FORMAT_UYVY;
-	case AV_PIX_FMT_RGBA:    return VIDEO_FORMAT_RGBA;
-	case AV_PIX_FMT_BGRA:    return VIDEO_FORMAT_BGRA;
-	case AV_PIX_FMT_BGR0:    return VIDEO_FORMAT_BGRX;
+	case AV_PIX_FMT_NONE:
+		return VIDEO_FORMAT_NONE;
+	case AV_PIX_FMT_YUV420P:
+		return VIDEO_FORMAT_I420;
+	case AV_PIX_FMT_NV12:
+		return VIDEO_FORMAT_NV12;
+	case AV_PIX_FMT_YUYV422:
+		return VIDEO_FORMAT_YUY2;
+	case AV_PIX_FMT_YUV444P:
+		return VIDEO_FORMAT_I444;
+	case AV_PIX_FMT_UYVY422:
+		return VIDEO_FORMAT_UYVY;
+	case AV_PIX_FMT_RGBA:
+		return VIDEO_FORMAT_RGBA;
+	case AV_PIX_FMT_BGRA:
+		return VIDEO_FORMAT_BGRA;
+	case AV_PIX_FMT_BGR0:
+		return VIDEO_FORMAT_BGRX;
+	case AV_PIX_FMT_YUVA420P:
+		return VIDEO_FORMAT_I40A;
+	case AV_PIX_FMT_YUVA422P:
+		return VIDEO_FORMAT_I42A;
+	case AV_PIX_FMT_YUVA444P:
+		return VIDEO_FORMAT_YUVA;
 	default:;
 	}
 
@@ -47,20 +63,52 @@ static inline enum video_format convert_pixel_format(int f)
 static inline enum audio_format convert_sample_format(int f)
 {
 	switch (f) {
-	case AV_SAMPLE_FMT_U8:   return AUDIO_FORMAT_U8BIT;
-	case AV_SAMPLE_FMT_S16:  return AUDIO_FORMAT_16BIT;
-	case AV_SAMPLE_FMT_S32:  return AUDIO_FORMAT_32BIT;
-	case AV_SAMPLE_FMT_FLT:  return AUDIO_FORMAT_FLOAT;
-	case AV_SAMPLE_FMT_U8P:  return AUDIO_FORMAT_U8BIT_PLANAR;
-	case AV_SAMPLE_FMT_S16P: return AUDIO_FORMAT_16BIT_PLANAR;
-	case AV_SAMPLE_FMT_S32P: return AUDIO_FORMAT_32BIT_PLANAR;
-	case AV_SAMPLE_FMT_FLTP: return AUDIO_FORMAT_FLOAT_PLANAR;
+	case AV_SAMPLE_FMT_U8:
+		return AUDIO_FORMAT_U8BIT;
+	case AV_SAMPLE_FMT_S16:
+		return AUDIO_FORMAT_16BIT;
+	case AV_SAMPLE_FMT_S32:
+		return AUDIO_FORMAT_32BIT;
+	case AV_SAMPLE_FMT_FLT:
+		return AUDIO_FORMAT_FLOAT;
+	case AV_SAMPLE_FMT_U8P:
+		return AUDIO_FORMAT_U8BIT_PLANAR;
+	case AV_SAMPLE_FMT_S16P:
+		return AUDIO_FORMAT_16BIT_PLANAR;
+	case AV_SAMPLE_FMT_S32P:
+		return AUDIO_FORMAT_32BIT_PLANAR;
+	case AV_SAMPLE_FMT_FLTP:
+		return AUDIO_FORMAT_FLOAT_PLANAR;
 	default:;
 	}
 
 	return AUDIO_FORMAT_UNKNOWN;
 }
 
+static inline enum speaker_layout convert_speaker_layout(uint8_t channels)
+{
+	switch (channels) {
+	case 0:
+		return SPEAKERS_UNKNOWN;
+	case 1:
+		return SPEAKERS_MONO;
+	case 2:
+		return SPEAKERS_STEREO;
+	case 3:
+		return SPEAKERS_2POINT1;
+	case 4:
+		return SPEAKERS_4POINT0;
+	case 5:
+		return SPEAKERS_4POINT1;
+	case 6:
+		return SPEAKERS_5POINT1;
+	case 8:
+		return SPEAKERS_7POINT1;
+	default:
+		return SPEAKERS_UNKNOWN;
+	}
+}
+
 static inline enum video_colorspace convert_color_space(enum AVColorSpace s)
 {
 	return s == AVCOL_SPC_BT709 ? VIDEO_CS_709 : VIDEO_CS_DEFAULT;
@@ -72,7 +120,7 @@ static inline enum video_range_type convert_color_range(enum AVColorRange r)
 }
 
 static inline struct mp_decode *get_packet_decoder(mp_media_t *media,
-		AVPacket *pkt)
+						   AVPacket *pkt)
 {
 	if (media->has_audio && pkt->stream_index == media->a.stream->index)
 		return &media->a;
@@ -91,9 +139,9 @@ static int mp_media_next_packet(mp_media_t *media)
 
 	int ret = av_read_frame(media->fmt, &pkt);
 	if (ret < 0) {
-		if (ret != AVERROR_EOF)
+		if (ret != AVERROR_EOF && ret != AVERROR_EXIT)
 			blog(LOG_WARNING, "MP: av_read_frame failed: %s (%d)",
-					av_err2str(ret), ret);
+			     av_err2str(ret), ret);
 		return ret;
 	}
 
@@ -144,7 +192,7 @@ static inline int get_sws_range(enum AVColorRange r)
 	return r == AVCOL_RANGE_JPEG ? 1 : 0;
 }
 
-#define FIXED_1_0 (1<<16)
+#define FIXED_1_0 (1 << 16)
 
 static bool mp_media_init_scaling(mp_media_t *m)
 {
@@ -152,23 +200,23 @@ static bool mp_media_init_scaling(mp_media_t *m)
 	int range = get_sws_range(m->v.decoder->color_range);
 	const int *coeff = sws_getCoefficients(space);
 
-	m->swscale = sws_getCachedContext(NULL,
-			m->v.decoder->width, m->v.decoder->height,
-			m->v.decoder->pix_fmt,
-			m->v.decoder->width, m->v.decoder->height,
-			m->scale_format,
-			SWS_FAST_BILINEAR, NULL, NULL, NULL);
+	m->swscale = sws_getCachedContext(NULL, m->v.decoder->width,
+					  m->v.decoder->height,
+					  m->v.decoder->pix_fmt,
+					  m->v.decoder->width,
+					  m->v.decoder->height, m->scale_format,
+					  SWS_FAST_BILINEAR, NULL, NULL, NULL);
 	if (!m->swscale) {
 		blog(LOG_WARNING, "MP: Failed to initialize scaler");
 		return false;
 	}
 
 	sws_setColorspaceDetails(m->swscale, coeff, range, coeff, range, 0,
-			FIXED_1_0, FIXED_1_0);
+				 FIXED_1_0, FIXED_1_0);
 
 	int ret = av_image_alloc(m->scale_pic, m->scale_linesizes,
-			m->v.decoder->width, m->v.decoder->height,
-			m->scale_format, 1);
+				 m->v.decoder->width, m->v.decoder->height,
+				 m->scale_format, 1);
 	if (ret < 0) {
 		blog(LOG_WARNING, "MP: Failed to create scale pic data");
 		return false;
@@ -182,7 +230,7 @@ static bool mp_media_prepare_frames(mp_media_t *m)
 	while (!mp_media_ready_to_start(m)) {
 		if (!m->eof) {
 			int ret = mp_media_next_packet(m);
-			if (ret == AVERROR_EOF)
+			if (ret == AVERROR_EOF || ret == AVERROR_EXIT)
 				m->eof = true;
 			else if (ret < 0)
 				return false;
@@ -234,8 +282,7 @@ static inline int64_t mp_media_get_base_pts(mp_media_t *m)
 	return base_ts;
 }
 
-static inline bool mp_media_can_play_frame(mp_media_t *m,
-		struct mp_decode *d)
+static inline bool mp_media_can_play_frame(mp_media_t *m, struct mp_decode *d)
 {
 	return d->frame_ready && d->frame_pts <= m->next_pts_ns;
 }
@@ -256,12 +303,12 @@ static void mp_media_next_audio(mp_media_t *m)
 	for (size_t i = 0; i < MAX_AV_PLANES; i++)
 		audio.data[i] = f->data[i];
 
-	audio.samples_per_sec = f->sample_rate;
-	audio.speakers = (enum speaker_layout)f->channels;
+	audio.samples_per_sec = f->sample_rate * m->speed / 100;
+	audio.speakers = convert_speaker_layout(f->channels);
 	audio.format = convert_sample_format(f->format);
 	audio.frames = f->nb_samples;
 	audio.timestamp = m->base_ts + d->frame_pts - m->start_ts +
-		m->play_sys_ts - base_sys_ts;
+			  m->play_sys_ts - base_sys_ts;
 
 	if (audio.format == AUDIO_FORMAT_UNKNOWN)
 		return;
@@ -292,10 +339,9 @@ static void mp_media_next_video(mp_media_t *m, bool preload)
 
 	bool flip = false;
 	if (m->swscale) {
-		int ret = sws_scale(m->swscale,
-				(const uint8_t *const *)f->data, f->linesize,
-				0, f->height,
-				m->scale_pic, m->scale_linesizes);
+		int ret = sws_scale(m->swscale, (const uint8_t *const *)f->data,
+				    f->linesize, 0, f->height, m->scale_pic,
+				    m->scale_linesizes);
 		if (ret < 0)
 			return;
 
@@ -318,25 +364,22 @@ static void mp_media_next_video(mp_media_t *m, bool preload)
 		frame->data[0] -= frame->linesize[0] * (f->height - 1);
 
 	new_format = convert_pixel_format(m->scale_format);
-	new_space  = convert_color_space(f->colorspace);
-	new_range  = m->force_range == VIDEO_RANGE_DEFAULT
-		? convert_color_range(f->color_range)
-		: m->force_range;
+	new_space = convert_color_space(f->colorspace);
+	new_range = m->force_range == VIDEO_RANGE_DEFAULT
+			    ? convert_color_range(f->color_range)
+			    : m->force_range;
 
-	if (new_format != frame->format ||
-	    new_space  != m->cur_space  ||
-	    new_range  != m->cur_range) {
+	if (new_format != frame->format || new_space != m->cur_space ||
+	    new_range != m->cur_range) {
 		bool success;
 
 		frame->format = new_format;
 		frame->full_range = new_range == VIDEO_RANGE_FULL;
 
-		success = video_format_get_parameters(
-				new_space,
-				new_range,
-				frame->color_matrix,
-				frame->color_range_min,
-				frame->color_range_max);
+		success = video_format_get_parameters(new_space, new_range,
+						      frame->color_matrix,
+						      frame->color_range_min,
+						      frame->color_range_max);
 
 		frame->format = new_format;
 		m->cur_space = new_space;
@@ -352,7 +395,7 @@ static void mp_media_next_video(mp_media_t *m, bool preload)
 		return;
 
 	frame->timestamp = m->base_ts + d->frame_pts - m->start_ts +
-		m->play_sys_ts - base_sys_ts;
+			   m->play_sys_ts - base_sys_ts;
 	frame->width = f->width;
 	frame->height = f->height;
 	frame->flip = flip;
@@ -404,14 +447,15 @@ static bool mp_media_reset(mp_media_t *m)
 	}
 
 	int64_t seek_target = seek_flags == AVSEEK_FLAG_BACKWARD
-		? av_rescale_q(seek_pos, AV_TIME_BASE_Q, stream->time_base)
-		: seek_pos;
+				      ? av_rescale_q(seek_pos, AV_TIME_BASE_Q,
+						     stream->time_base)
+				      : seek_pos;
 
 	if (m->is_local_file) {
 		int ret = av_seek_frame(m->fmt, 0, seek_target, seek_flags);
 		if (ret < 0) {
 			blog(LOG_WARNING, "MP: Failed to seek: %s",
-					av_err2str(ret));
+			     av_err2str(ret));
 		}
 	}
 
@@ -522,8 +566,10 @@ static bool init_avformat(mp_media_t *m)
 	if (m->format_name && *m->format_name) {
 		format = av_find_input_format(m->format_name);
 		if (!format)
-			blog(LOG_INFO, "MP: Unable to find input format for "
-					"'%s'", m->path);
+			blog(LOG_INFO,
+			     "MP: Unable to find input format for "
+			     "'%s'",
+			     m->path);
 	}
 
 	AVDictionary *opts = NULL;
@@ -531,11 +577,13 @@ static bool init_avformat(mp_media_t *m)
 		av_dict_set_int(&opts, "buffer_size", m->buffering, 0);
 
 	m->fmt = avformat_alloc_context();
-	m->fmt->interrupt_callback.callback = interrupt_callback;
-	m->fmt->interrupt_callback.opaque = m;
+	if (!m->is_local_file) {
+		m->fmt->interrupt_callback.callback = interrupt_callback;
+		m->fmt->interrupt_callback.opaque = m;
+	}
 
 	int ret = avformat_open_input(&m->fmt, m->path, format,
-			opts ? &opts : NULL);
+				      opts ? &opts : NULL);
 	av_dict_free(&opts);
 
 	if (ret < 0) {
@@ -545,7 +593,7 @@ static bool init_avformat(mp_media_t *m)
 
 	if (avformat_find_stream_info(m->fmt, NULL) < 0) {
 		blog(LOG_WARNING, "MP: Failed to find stream info for '%s'",
-				m->path);
+		     m->path);
 		return false;
 	}
 
@@ -553,8 +601,10 @@ static bool init_avformat(mp_media_t *m)
 	m->has_audio = mp_decode_init(m, AVMEDIA_TYPE_AUDIO, m->hw);
 
 	if (!m->has_video && !m->has_audio) {
-		blog(LOG_WARNING, "MP: Could not initialize audio or video: "
-				"'%s'", m->path);
+		blog(LOG_WARNING,
+		     "MP: Could not initialize audio or video: "
+		     "'%s'",
+		     m->path);
 		return false;
 	}
 
@@ -637,9 +687,7 @@ static void *mp_media_thread_start(void *opaque)
 }
 
 static inline bool mp_media_init_internal(mp_media_t *m,
-		const char *path,
-		const char *format_name,
-		bool hw)
+					  const struct mp_media_info *info)
 {
 	if (pthread_mutex_init(&m->mutex, NULL) != 0) {
 		blog(LOG_WARNING, "MP: Failed to init mutex");
@@ -650,9 +698,9 @@ static inline bool mp_media_init_internal(mp_media_t *m,
 		return false;
 	}
 
-	m->path = path ? bstrdup(path) : NULL;
-	m->format_name = format_name ? bstrdup(format_name) : NULL;
-	m->hw = hw;
+	m->path = info->path ? bstrdup(info->path) : NULL;
+	m->format_name = info->format ? bstrdup(info->format) : NULL;
+	m->hw = info->hardware_decoding;
 
 	if (pthread_create(&m->thread, NULL, mp_media_thread_start, m) != 0) {
 		blog(LOG_WARNING, "MP: Could not create media thread");
@@ -663,35 +711,30 @@ static inline bool mp_media_init_internal(mp_media_t *m,
 	return true;
 }
 
-bool mp_media_init(mp_media_t *media,
-		const char *path,
-		const char *format,
-		int buffering,
-		void *opaque,
-		mp_video_cb v_cb,
-		mp_audio_cb a_cb,
-		mp_stop_cb stop_cb,
-		mp_video_cb v_preload_cb,
-		bool hw_decoding,
-		bool is_local_file,
-		enum video_range_type force_range)
+bool mp_media_init(mp_media_t *media, const struct mp_media_info *info)
 {
 	memset(media, 0, sizeof(*media));
 	pthread_mutex_init_value(&media->mutex);
-	media->opaque = opaque;
-	media->v_cb = v_cb;
-	media->a_cb = a_cb;
-	media->stop_cb = stop_cb;
-	media->v_preload_cb = v_preload_cb;
-	media->force_range = force_range;
-	media->buffering = buffering;
-	media->is_local_file = is_local_file;
+	media->opaque = info->opaque;
+	media->v_cb = info->v_cb;
+	media->a_cb = info->a_cb;
+	media->stop_cb = info->stop_cb;
+	media->v_preload_cb = info->v_preload_cb;
+	media->force_range = info->force_range;
+	media->buffering = info->buffering;
+	media->speed = info->speed;
+	media->is_local_file = info->is_local_file;
+
+	if (!info->is_local_file || media->speed < 1 || media->speed > 200)
+		media->speed = 100;
 
 	static bool initialized = false;
 	if (!initialized) {
+#if LIBAVCODEC_VERSION_INT < AV_VERSION_INT(58, 9, 100)
 		av_register_all();
-		avdevice_register_all();
 		avcodec_register_all();
+#endif
+		avdevice_register_all();
 		avformat_network_init();
 		initialized = true;
 	}
@@ -699,7 +742,7 @@ bool mp_media_init(mp_media_t *media,
 	if (!base_sys_ts)
 		base_sys_ts = (int64_t)os_gettime_ns();
 
-	if (!mp_media_init_internal(media, path, format, hw_decoding)) {
+	if (!mp_media_init_internal(media, info)) {
 		mp_media_free(media);
 		return false;
 	}
