@@ -6,18 +6,23 @@
 #include "../funchook.h"
 #include "d3d9-patches.hpp"
 
-typedef HRESULT (STDMETHODCALLTYPE *present_t)(IDirect3DDevice9*,
-		CONST RECT*, CONST RECT*, HWND, CONST RGNDATA*);
-typedef HRESULT (STDMETHODCALLTYPE *present_ex_t)(IDirect3DDevice9*,
-		CONST RECT*, CONST RECT*, HWND, CONST RGNDATA*, DWORD);
-typedef HRESULT (STDMETHODCALLTYPE *present_swap_t)(IDirect3DSwapChain9*,
-		CONST RECT*, CONST RECT*, HWND, CONST RGNDATA*, DWORD);
-typedef HRESULT (STDMETHODCALLTYPE *reset_t)(IDirect3DDevice9*,
-		D3DPRESENT_PARAMETERS*);
-typedef HRESULT (STDMETHODCALLTYPE *reset_ex_t)(IDirect3DDevice9*,
-		D3DPRESENT_PARAMETERS*, D3DDISPLAYMODEEX*);
+typedef HRESULT(STDMETHODCALLTYPE *present_t)(IDirect3DDevice9 *, CONST RECT *,
+					      CONST RECT *, HWND,
+					      CONST RGNDATA *);
+typedef HRESULT(STDMETHODCALLTYPE *present_ex_t)(IDirect3DDevice9 *,
+						 CONST RECT *, CONST RECT *,
+						 HWND, CONST RGNDATA *, DWORD);
+typedef HRESULT(STDMETHODCALLTYPE *present_swap_t)(IDirect3DSwapChain9 *,
+						   CONST RECT *, CONST RECT *,
+						   HWND, CONST RGNDATA *,
+						   DWORD);
+typedef HRESULT(STDMETHODCALLTYPE *reset_t)(IDirect3DDevice9 *,
+					    D3DPRESENT_PARAMETERS *);
+typedef HRESULT(STDMETHODCALLTYPE *reset_ex_t)(IDirect3DDevice9 *,
+					       D3DPRESENT_PARAMETERS *,
+					       D3DDISPLAYMODEEX *);
 
-typedef HRESULT (WINAPI *createfactory1_t)(REFIID, void **);
+typedef HRESULT(WINAPI *createfactory1_t)(REFIID, void **);
 
 static struct func_hook present;
 static struct func_hook present_ex;
@@ -26,34 +31,34 @@ static struct func_hook reset;
 static struct func_hook reset_ex;
 
 struct d3d9_data {
-	HMODULE                d3d9;
-	IDirect3DDevice9       *device; /* do not release */
-	uint32_t               cx;
-	uint32_t               cy;
-	D3DFORMAT              d3d9_format;
-	DXGI_FORMAT            dxgi_format;
-	bool                   using_shtex : 1;
-	bool                   using_scale : 1;
+	HMODULE d3d9;
+	IDirect3DDevice9 *device; /* do not release */
+	uint32_t cx;
+	uint32_t cy;
+	D3DFORMAT d3d9_format;
+	DXGI_FORMAT dxgi_format;
+	bool using_shtex;
+	bool using_scale;
 
 	/* shared texture */
-	IDirect3DSurface9      *d3d9_copytex;
-	ID3D11Device           *d3d11_device;
-	ID3D11DeviceContext    *d3d11_context;
-	ID3D11Resource         *d3d11_tex;
-	struct shtex_data      *shtex_info;
-	HANDLE                 handle;
-	int                    patch;
+	IDirect3DSurface9 *d3d9_copytex;
+	ID3D11Device *d3d11_device;
+	ID3D11DeviceContext *d3d11_context;
+	ID3D11Resource *d3d11_tex;
+	struct shtex_data *shtex_info;
+	HANDLE handle;
+	int patch;
 
 	/* shared memory */
-	IDirect3DSurface9      *copy_surfaces[NUM_BUFFERS];
-	IDirect3DSurface9      *render_targets[NUM_BUFFERS];
-	IDirect3DQuery9        *queries[NUM_BUFFERS];
-	struct shmem_data      *shmem_info;
-	bool                   texture_mapped[NUM_BUFFERS];
-	volatile bool          issued_queries[NUM_BUFFERS];
-	uint32_t               pitch;
-	int                    cur_tex;
-	int                    copy_wait;
+	IDirect3DSurface9 *copy_surfaces[NUM_BUFFERS];
+	IDirect3DSurface9 *render_targets[NUM_BUFFERS];
+	IDirect3DQuery9 *queries[NUM_BUFFERS];
+	struct shmem_data *shmem_info;
+	bool texture_mapped[NUM_BUFFERS];
+	volatile bool issued_queries[NUM_BUFFERS];
+	uint32_t pitch;
+	int cur_tex;
+	int copy_wait;
 };
 
 static struct d3d9_data data = {};
@@ -93,16 +98,18 @@ static void d3d9_free()
 static DXGI_FORMAT d3d9_to_dxgi_format(D3DFORMAT format)
 {
 	switch ((unsigned long)format) {
-	case D3DFMT_A2B10G10R10: return DXGI_FORMAT_R10G10B10A2_UNORM;
-	case D3DFMT_A8R8G8B8:    return DXGI_FORMAT_B8G8R8A8_UNORM;
-	case D3DFMT_X8R8G8B8:    return DXGI_FORMAT_B8G8R8X8_UNORM;
+	case D3DFMT_A2B10G10R10:
+		return DXGI_FORMAT_R10G10B10A2_UNORM;
+	case D3DFMT_A8R8G8B8:
+		return DXGI_FORMAT_B8G8R8A8_UNORM;
+	case D3DFMT_X8R8G8B8:
+		return DXGI_FORMAT_B8G8R8X8_UNORM;
 	}
 
 	return DXGI_FORMAT_UNKNOWN;
 }
 
-const static D3D_FEATURE_LEVEL feature_levels[] =
-{
+const static D3D_FEATURE_LEVEL feature_levels[] = {
 	D3D_FEATURE_LEVEL_11_0,
 	D3D_FEATURE_LEVEL_10_1,
 	D3D_FEATURE_LEVEL_10_0,
@@ -132,21 +139,21 @@ static inline bool shex_init_d3d11()
 		return false;
 	}
 
-	create_factory = (createfactory1_t)GetProcAddress(dxgi,
-			"CreateDXGIFactory1");
+	create_factory =
+		(createfactory1_t)GetProcAddress(dxgi, "CreateDXGIFactory1");
 	if (!create_factory) {
 		hlog("d3d9_init: Failed to get CreateDXGIFactory1 address");
 		return false;
 	}
 
-	create_device = (PFN_D3D11_CREATE_DEVICE)GetProcAddress(d3d11,
-			"D3D11CreateDevice");
+	create_device = (PFN_D3D11_CREATE_DEVICE)GetProcAddress(
+		d3d11, "D3D11CreateDevice");
 	if (!create_device) {
 		hlog("d3d9_init: Failed to get D3D11CreateDevice address");
 		return false;
 	}
 
-	hr = create_factory(__uuidof(IDXGIFactory1), (void**)&factory);
+	hr = create_factory(__uuidof(IDXGIFactory1), (void **)&factory);
 	if (FAILED(hr)) {
 		hlog_hr("d3d9_init: Failed to create factory object", hr);
 		return false;
@@ -160,11 +167,11 @@ static inline bool shex_init_d3d11()
 		return false;
 	}
 
-	hr = create_device(adapter, D3D_DRIVER_TYPE_UNKNOWN, nullptr,
-			0, feature_levels,
-			sizeof(feature_levels) / sizeof(D3D_FEATURE_LEVEL),
-			D3D11_SDK_VERSION, &data.d3d11_device, &level_used,
-			&data.d3d11_context);
+	hr = create_device(adapter, D3D_DRIVER_TYPE_UNKNOWN, nullptr, 0,
+			   feature_levels,
+			   sizeof(feature_levels) / sizeof(D3D_FEATURE_LEVEL),
+			   D3D11_SDK_VERSION, &data.d3d11_device, &level_used,
+			   &data.d3d11_context);
 	adapter->Release();
 
 	if (FAILED(hr)) {
@@ -181,30 +188,29 @@ static inline bool d3d9_shtex_init_shtex()
 	HRESULT hr;
 
 	D3D11_TEXTURE2D_DESC desc = {};
-	desc.Width                = data.cx;
-	desc.Height               = data.cy;
-	desc.Format               = data.dxgi_format;
-	desc.MipLevels            = 1;
-	desc.ArraySize            = 1;
-	desc.SampleDesc.Count     = 1;
-	desc.Usage                = D3D11_USAGE_DEFAULT;
-	desc.MiscFlags            = D3D11_RESOURCE_MISC_SHARED;
-	desc.BindFlags            = D3D11_BIND_RENDER_TARGET |
-	                            D3D11_BIND_SHADER_RESOURCE;
+	desc.Width = data.cx;
+	desc.Height = data.cy;
+	desc.Format = data.dxgi_format;
+	desc.MipLevels = 1;
+	desc.ArraySize = 1;
+	desc.SampleDesc.Count = 1;
+	desc.Usage = D3D11_USAGE_DEFAULT;
+	desc.MiscFlags = D3D11_RESOURCE_MISC_SHARED;
+	desc.BindFlags = D3D11_BIND_RENDER_TARGET | D3D11_BIND_SHADER_RESOURCE;
 
-	hr = data.d3d11_device->CreateTexture2D(&desc, nullptr,
-			(ID3D11Texture2D**)&data.d3d11_tex);
+	hr = data.d3d11_device->CreateTexture2D(
+		&desc, nullptr, (ID3D11Texture2D **)&data.d3d11_tex);
 	if (FAILED(hr)) {
 		hlog_hr("d3d9_shtex_init_shtex: Failed to create D3D11 texture",
-				hr);
+			hr);
 		return false;
 	}
 
 	hr = data.d3d11_tex->QueryInterface(__uuidof(IDXGIResource),
-			(void**)&res);
+					    (void **)&res);
 	if (FAILED(hr)) {
 		hlog_hr("d3d9_shtex_init_shtex: Failed to query IDXGIResource",
-				hr);
+			hr);
 		return false;
 	}
 
@@ -213,7 +219,7 @@ static inline bool d3d9_shtex_init_shtex()
 
 	if (FAILED(hr)) {
 		hlog_hr("d3d9_shtex_init_shtex: Failed to get shared handle",
-				hr);
+			hr);
 		return false;
 	}
 
@@ -233,10 +239,10 @@ static inline bool d3d9_shtex_init_copytex()
 	HRESULT hr;
 
 	if (offsets.d3d9_clsoff && offsets.is_d3d9ex_clsoff) {
-		uint8_t *device_ptr = (uint8_t*)(data.device);
+		uint8_t *device_ptr = (uint8_t *)(data.device);
 		uint8_t *d3d9_ptr =
-			*(uint8_t**)(device_ptr + offsets.d3d9_clsoff);
-		p_is_d3d9 = (BOOL*)(d3d9_ptr + offsets.is_d3d9ex_clsoff);
+			*(uint8_t **)(device_ptr + offsets.d3d9_clsoff);
+		p_is_d3d9 = (BOOL *)(d3d9_ptr + offsets.is_d3d9ex_clsoff);
 	} else {
 		patch_addr = get_d3d9_patch_addr(data.d3d9, data.patch);
 	}
@@ -248,14 +254,14 @@ static inline bool d3d9_shtex_init_copytex()
 	} else if (patch_addr) {
 		patch_size = patch[data.patch].size;
 		VirtualProtect(patch_addr, patch_size, PAGE_EXECUTE_READWRITE,
-				&protect_val);
+			       &protect_val);
 		memcpy(saved_data, patch_addr, patch_size);
 		memcpy(patch_addr, patch[data.patch].data, patch_size);
 	}
 
 	hr = data.device->CreateTexture(data.cx, data.cy, 1,
-			D3DUSAGE_RENDERTARGET, data.d3d9_format,
-			D3DPOOL_DEFAULT, &tex, &data.handle);
+					D3DUSAGE_RENDERTARGET, data.d3d9_format,
+					D3DPOOL_DEFAULT, &tex, &data.handle);
 
 	if (p_is_d3d9) {
 		*p_is_d3d9 = was_d3d9ex;
@@ -263,12 +269,12 @@ static inline bool d3d9_shtex_init_copytex()
 	} else if (patch_addr && patch_size) {
 		memcpy(patch_addr, saved_data, patch_size);
 		VirtualProtect(patch_addr, patch_size, protect_val,
-				&protect_val);
+			       &protect_val);
 	}
 
 	if (FAILED(hr)) {
 		hlog_hr("d3d9_shtex_init_copytex: Failed to create shared texture",
-				hr);
+			hr);
 		return false;
 	}
 
@@ -276,7 +282,8 @@ static inline bool d3d9_shtex_init_copytex()
 	tex->Release();
 
 	if (FAILED(hr)) {
-		hlog_hr("d3d9_shtex_init_copytex: Failed to get surface level", hr);
+		hlog_hr("d3d9_shtex_init_copytex: Failed to get surface level",
+			hr);
 		return false;
 	}
 
@@ -296,8 +303,8 @@ static bool d3d9_shtex_init(uint32_t cx, uint32_t cy, HWND window)
 	if (!d3d9_shtex_init_copytex()) {
 		return false;
 	}
-	if (!capture_init_shtex(&data.shtex_info, window, cx, cy,
-				data.cx, data.cy, data.dxgi_format, false,
+	if (!capture_init_shtex(&data.shtex_info, window, cx, cy, data.cx,
+				data.cy, data.dxgi_format, false,
 				(uintptr_t)data.handle)) {
 		return false;
 	}
@@ -310,40 +317,43 @@ static bool d3d9_shmem_init_buffers(size_t buffer)
 {
 	HRESULT hr;
 
-	hr = data.device->CreateOffscreenPlainSurface(data.cx, data.cy,
-			data.d3d9_format, D3DPOOL_SYSTEMMEM,
-			&data.copy_surfaces[buffer], nullptr);
+	hr = data.device->CreateOffscreenPlainSurface(
+		data.cx, data.cy, data.d3d9_format, D3DPOOL_SYSTEMMEM,
+		&data.copy_surfaces[buffer], nullptr);
 	if (FAILED(hr)) {
 		hlog_hr("d3d9_shmem_init_buffers: Failed to create surface",
-				hr);
+			hr);
 		return false;
 	}
 
 	if (buffer == 0) {
 		D3DLOCKED_RECT rect;
 		hr = data.copy_surfaces[buffer]->LockRect(&rect, nullptr,
-				D3DLOCK_READONLY);
+							  D3DLOCK_READONLY);
 		if (FAILED(hr)) {
 			hlog_hr("d3d9_shmem_init_buffers: Failed to lock "
-			        "buffer", hr);
+				"buffer",
+				hr);
 			return false;
 		}
 
 		data.pitch = rect.Pitch;
 		data.copy_surfaces[buffer]->UnlockRect();
-	}	
+	}
 
-	hr = data.device->CreateRenderTarget(data.cx, data.cy,
-			data.d3d9_format, D3DMULTISAMPLE_NONE, 0, false,
-			&data.render_targets[buffer], nullptr);
+	hr = data.device->CreateRenderTarget(data.cx, data.cy, data.d3d9_format,
+					     D3DMULTISAMPLE_NONE, 0, false,
+					     &data.render_targets[buffer],
+					     nullptr);
 	if (FAILED(hr)) {
 		hlog_hr("d3d9_shmem_init_buffers: Failed to create render "
-		        "target", hr);
+			"target",
+			hr);
 		return false;
 	}
 
 	hr = data.device->CreateQuery(D3DQUERYTYPE_EVENT,
-			&data.queries[buffer]);
+				      &data.queries[buffer]);
 	if (FAILED(hr)) {
 		hlog_hr("d3d9_shmem_init_buffers: Failed to create query", hr);
 		return false;
@@ -361,9 +371,8 @@ static bool d3d9_shmem_init(uint32_t cx, uint32_t cy, HWND window)
 			return false;
 		}
 	}
-	if (!capture_init_shmem(&data.shmem_info, window, cx, cy,
-				data.cx, data.cy, data.pitch, data.dxgi_format,
-				false)) {
+	if (!capture_init_shmem(&data.shmem_info, window, cx, cy, data.cx,
+				data.cy, data.pitch, data.dxgi_format, false)) {
 		return false;
 	}
 
@@ -387,7 +396,8 @@ static bool d3d9_get_swap_desc(D3DPRESENT_PARAMETERS &pp)
 
 	if (FAILED(hr)) {
 		hlog_hr("d3d9_get_swap_desc: Failed to get "
-		        "presentation parameters", hr);
+			"presentation parameters",
+			hr);
 		return false;
 	}
 
@@ -395,7 +405,7 @@ static bool d3d9_get_swap_desc(D3DPRESENT_PARAMETERS &pp)
 }
 
 static bool d3d9_init_format_backbuffer(uint32_t &cx, uint32_t &cy,
-		HWND &window)
+					HWND &window)
 {
 	IDirect3DSurface9 *back_buffer = nullptr;
 	D3DPRESENT_PARAMETERS pp;
@@ -416,7 +426,8 @@ static bool d3d9_init_format_backbuffer(uint32_t &cx, uint32_t &cy,
 
 	if (FAILED(hr)) {
 		hlog_hr("d3d9_init_format_backbuffer: Failed to get "
-		        "backbuffer descriptor", hr);
+			"backbuffer descriptor",
+			hr);
 		return false;
 	}
 
@@ -480,7 +491,7 @@ static void d3d9_init(IDirect3DDevice9 *device)
 	data.device = device;
 
 	hr = device->QueryInterface(__uuidof(IDirect3DDevice9Ex),
-			(void**)&d3d9ex);
+				    (void **)&d3d9ex);
 	if (SUCCEEDED(hr)) {
 		d3d9ex->Release();
 		data.patch = -1;
@@ -508,7 +519,7 @@ static void d3d9_init(IDirect3DDevice9 *device)
 }
 
 static inline HRESULT get_backbuffer(IDirect3DDevice9 *device,
-		IDirect3DSurface9 **surface)
+				     IDirect3DSurface9 **surface)
 {
 	static bool use_backbuffer = false;
 	static bool checked_exceptions = false;
@@ -521,7 +532,7 @@ static inline HRESULT get_backbuffer(IDirect3DDevice9 *device,
 
 	if (use_backbuffer) {
 		return device->GetBackBuffer(0, 0, D3DBACKBUFFER_TYPE_MONO,
-				surface);
+					     surface);
 	} else {
 		return device->GetRenderTarget(0, surface);
 	}
@@ -535,7 +546,7 @@ static inline void d3d9_shtex_capture(IDirect3DSurface9 *backbuffer)
 	filter = data.using_scale ? D3DTEXF_LINEAR : D3DTEXF_NONE;
 
 	hr = data.device->StretchRect(backbuffer, nullptr, data.d3d9_copytex,
-			nullptr, filter);
+				      nullptr, filter);
 	if (FAILED(hr))
 		hlog_hr("d3d9_shtex_capture: StretchRect failed", hr);
 }
@@ -574,12 +585,12 @@ static inline void d3d9_shmem_capture(IDirect3DSurface9 *backbuffer)
 
 	d3d9_shmem_capture_queue_copy();
 
-	next_tex = (data.cur_tex == NUM_BUFFERS - 1) ?  0 : data.cur_tex + 1;
+	next_tex = (data.cur_tex == NUM_BUFFERS - 1) ? 0 : data.cur_tex + 1;
 	filter = data.using_scale ? D3DTEXF_LINEAR : D3DTEXF_NONE;
 	copy = data.render_targets[data.cur_tex];
 
 	hr = data.device->StretchRect(backbuffer, nullptr, copy, nullptr,
-			filter);
+				      filter);
 
 	if (FAILED(hr)) {
 		hlog_hr("d3d9_shmem_capture: StretchRect failed", hr);
@@ -601,7 +612,8 @@ static inline void d3d9_shmem_capture(IDirect3DSurface9 *backbuffer)
 		hr = data.device->GetRenderTargetData(src, dst);
 		if (FAILED(hr)) {
 			hlog_hr("d3d9_shmem_capture: GetRenderTargetData "
-			        "failed", hr);
+				"failed",
+				hr);
 		}
 
 		data.queries[next_tex]->Issue(D3DISSUE_END);
@@ -612,7 +624,7 @@ static inline void d3d9_shmem_capture(IDirect3DSurface9 *backbuffer)
 }
 
 static void d3d9_capture(IDirect3DDevice9 *device,
-		IDirect3DSurface9 *backbuffer)
+			 IDirect3DSurface9 *backbuffer)
 {
 	if (capture_should_stop()) {
 		d3d9_free();
@@ -637,7 +649,7 @@ static void d3d9_capture(IDirect3DDevice9 *device,
 static int present_recurse = 0;
 
 static inline void present_begin(IDirect3DDevice9 *device,
-		IDirect3DSurface9 *&backbuffer)
+				 IDirect3DSurface9 *&backbuffer)
 {
 	HRESULT hr;
 
@@ -645,7 +657,8 @@ static inline void present_begin(IDirect3DDevice9 *device,
 		hr = get_backbuffer(device, &backbuffer);
 		if (FAILED(hr)) {
 			hlog_hr("d3d9_shmem_capture: Failed to get "
-				"backbuffer", hr);
+				"backbuffer",
+				hr);
 		}
 
 		if (!global_hook_info->capture_overlay) {
@@ -657,7 +670,7 @@ static inline void present_begin(IDirect3DDevice9 *device,
 }
 
 static inline void present_end(IDirect3DDevice9 *device,
-		IDirect3DSurface9 *backbuffer)
+			       IDirect3DSurface9 *backbuffer)
 {
 	present_recurse--;
 
@@ -676,8 +689,10 @@ static bool hooked_reset = false;
 static void setup_reset_hooks(IDirect3DDevice9 *device);
 
 static HRESULT STDMETHODCALLTYPE hook_present(IDirect3DDevice9 *device,
-		CONST RECT *src_rect, CONST RECT *dst_rect,
-		HWND override_window, CONST RGNDATA *dirty_region)
+					      CONST RECT *src_rect,
+					      CONST RECT *dst_rect,
+					      HWND override_window,
+					      CONST RGNDATA *dirty_region)
 {
 	IDirect3DSurface9 *backbuffer = nullptr;
 	HRESULT hr;
@@ -697,9 +712,9 @@ static HRESULT STDMETHODCALLTYPE hook_present(IDirect3DDevice9 *device,
 	return hr;
 }
 
-static HRESULT STDMETHODCALLTYPE hook_present_ex(IDirect3DDevice9 *device,
-		CONST RECT *src_rect, CONST RECT *dst_rect,
-		HWND override_window, CONST RGNDATA *dirty_region, DWORD flags)
+static HRESULT STDMETHODCALLTYPE hook_present_ex(
+	IDirect3DDevice9 *device, CONST RECT *src_rect, CONST RECT *dst_rect,
+	HWND override_window, CONST RGNDATA *dirty_region, DWORD flags)
 {
 	IDirect3DSurface9 *backbuffer = nullptr;
 	HRESULT hr;
@@ -712,7 +727,7 @@ static HRESULT STDMETHODCALLTYPE hook_present_ex(IDirect3DDevice9 *device,
 	unhook(&present_ex);
 	present_ex_t call = (present_ex_t)present_ex.call_addr;
 	hr = call(device, src_rect, dst_rect, override_window, dirty_region,
-			flags);
+		  flags);
 	rehook(&present_ex);
 
 	present_end(device, backbuffer);
@@ -720,9 +735,9 @@ static HRESULT STDMETHODCALLTYPE hook_present_ex(IDirect3DDevice9 *device,
 	return hr;
 }
 
-static HRESULT STDMETHODCALLTYPE hook_present_swap(IDirect3DSwapChain9 *swap,
-		CONST RECT *src_rect, CONST RECT *dst_rect,
-		HWND override_window, CONST RGNDATA *dirty_region, DWORD flags)
+static HRESULT STDMETHODCALLTYPE hook_present_swap(
+	IDirect3DSwapChain9 *swap, CONST RECT *src_rect, CONST RECT *dst_rect,
+	HWND override_window, CONST RGNDATA *dirty_region, DWORD flags)
 {
 	IDirect3DSurface9 *backbuffer = nullptr;
 	IDirect3DDevice9 *device = nullptr;
@@ -745,7 +760,7 @@ static HRESULT STDMETHODCALLTYPE hook_present_swap(IDirect3DSwapChain9 *swap,
 	unhook(&present_swap);
 	present_swap_t call = (present_swap_t)present_swap.call_addr;
 	hr = call(swap, src_rect, dst_rect, override_window, dirty_region,
-			flags);
+		  flags);
 	rehook(&present_swap);
 
 	if (device)
@@ -755,7 +770,7 @@ static HRESULT STDMETHODCALLTYPE hook_present_swap(IDirect3DSwapChain9 *swap,
 }
 
 static HRESULT STDMETHODCALLTYPE hook_reset(IDirect3DDevice9 *device,
-		D3DPRESENT_PARAMETERS *params)
+					    D3DPRESENT_PARAMETERS *params)
 {
 	HRESULT hr;
 
@@ -771,7 +786,8 @@ static HRESULT STDMETHODCALLTYPE hook_reset(IDirect3DDevice9 *device,
 }
 
 static HRESULT STDMETHODCALLTYPE hook_reset_ex(IDirect3DDevice9 *device,
-		D3DPRESENT_PARAMETERS *params, D3DDISPLAYMODEEX *dmex)
+					       D3DPRESENT_PARAMETERS *params,
+					       D3DDISPLAYMODEEX *dmex)
 {
 	HRESULT hr;
 
@@ -789,18 +805,18 @@ static HRESULT STDMETHODCALLTYPE hook_reset_ex(IDirect3DDevice9 *device,
 static void setup_reset_hooks(IDirect3DDevice9 *device)
 {
 	IDirect3DDevice9Ex *d3d9ex = nullptr;
-	uintptr_t *vtable = *(uintptr_t**)device;
+	uintptr_t *vtable = *(uintptr_t **)device;
 	HRESULT hr;
 
-	hook_init(&reset, (void*)vtable[16], (void*)hook_reset,
-			"IDirect3DDevice9::Reset");
+	hook_init(&reset, (void *)vtable[16], (void *)hook_reset,
+		  "IDirect3DDevice9::Reset");
 	rehook(&reset);
 
 	hr = device->QueryInterface(__uuidof(IDirect3DDevice9Ex),
-			(void**)&d3d9ex);
+				    (void **)&d3d9ex);
 	if (SUCCEEDED(hr)) {
-		hook_init(&reset_ex, (void*)vtable[132], (void*)hook_reset_ex,
-				"IDirect3DDevice9Ex::ResetEx");
+		hook_init(&reset_ex, (void *)vtable[132], (void *)hook_reset_ex,
+			  "IDirect3DDevice9Ex::ResetEx");
 		rehook(&reset_ex);
 
 		d3d9ex->Release();
@@ -809,12 +825,11 @@ static void setup_reset_hooks(IDirect3DDevice9 *device)
 	hooked_reset = true;
 }
 
-typedef HRESULT (WINAPI *d3d9create_ex_t)(UINT, IDirect3D9Ex**);
+typedef HRESULT(WINAPI *d3d9create_ex_t)(UINT, IDirect3D9Ex **);
 
-static bool manually_get_d3d9_addrs(HMODULE d3d9_module,
-		void **present_addr,
-		void **present_ex_addr,
-		void **present_swap_addr)
+static bool manually_get_d3d9_addrs(HMODULE d3d9_module, void **present_addr,
+				    void **present_ex_addr,
+				    void **present_swap_addr)
 {
 	d3d9create_ex_t create_ex;
 	D3DPRESENT_PARAMETERS pp;
@@ -826,7 +841,7 @@ static bool manually_get_d3d9_addrs(HMODULE d3d9_module,
 	hlog("D3D9 values invalid, manually obtaining");
 
 	create_ex = (d3d9create_ex_t)GetProcAddress(d3d9_module,
-			"Direct3DCreate9Ex");
+						    "Direct3DCreate9Ex");
 	if (!create_ex) {
 		hlog("Failed to load Direct3DCreate9Ex");
 		return false;
@@ -837,30 +852,30 @@ static bool manually_get_d3d9_addrs(HMODULE d3d9_module,
 	}
 
 	memset(&pp, 0, sizeof(pp));
-	pp.Windowed                 = 1;
-	pp.SwapEffect               = D3DSWAPEFFECT_FLIP;
-	pp.BackBufferFormat         = D3DFMT_A8R8G8B8;
-	pp.BackBufferCount          = 1;
-	pp.hDeviceWindow            = (HWND)dummy_window;
-	pp.PresentationInterval     = D3DPRESENT_INTERVAL_IMMEDIATE;
+	pp.Windowed = 1;
+	pp.SwapEffect = D3DSWAPEFFECT_FLIP;
+	pp.BackBufferFormat = D3DFMT_A8R8G8B8;
+	pp.BackBufferCount = 1;
+	pp.hDeviceWindow = (HWND)dummy_window;
+	pp.PresentationInterval = D3DPRESENT_INTERVAL_IMMEDIATE;
 
-	hr = d3d9ex->CreateDeviceEx(D3DADAPTER_DEFAULT, D3DDEVTYPE_HAL,
-			dummy_window,
-			D3DCREATE_HARDWARE_VERTEXPROCESSING |
-			D3DCREATE_NOWINDOWCHANGES, &pp, NULL, &device);
+	hr = d3d9ex->CreateDeviceEx(
+		D3DADAPTER_DEFAULT, D3DDEVTYPE_HAL, dummy_window,
+		D3DCREATE_HARDWARE_VERTEXPROCESSING | D3DCREATE_NOWINDOWCHANGES,
+		&pp, NULL, &device);
 	d3d9ex->Release();
 
 	if (SUCCEEDED(hr)) {
-		uintptr_t *vtable = *(uintptr_t**)device;
+		uintptr_t *vtable = *(uintptr_t **)device;
 		IDirect3DSwapChain9 *swap;
 
-		*present_addr = (void*)vtable[17];
-		*present_ex_addr = (void*)vtable[121];
+		*present_addr = (void *)vtable[17];
+		*present_ex_addr = (void *)vtable[121];
 
 		hr = device->GetSwapChain(0, &swap);
 		if (SUCCEEDED(hr)) {
-			vtable = *(uintptr_t**)swap;
-			*present_swap_addr = (void*)vtable[3];
+			vtable = *(uintptr_t **)swap;
+			*present_swap_addr = (void *)vtable[3];
 
 			swap->Release();
 		}
@@ -888,25 +903,25 @@ bool hook_d3d9(void)
 
 	d3d9_size = module_size(d3d9_module);
 
-	if (global_hook_info->offsets.d3d9.present      < d3d9_size &&
-	    global_hook_info->offsets.d3d9.present_ex   < d3d9_size &&
+	if (global_hook_info->offsets.d3d9.present < d3d9_size &&
+	    global_hook_info->offsets.d3d9.present_ex < d3d9_size &&
 	    global_hook_info->offsets.d3d9.present_swap < d3d9_size) {
 
-		present_addr = get_offset_addr(d3d9_module,
-				global_hook_info->offsets.d3d9.present);
-		present_ex_addr = get_offset_addr(d3d9_module,
-				global_hook_info->offsets.d3d9.present_ex);
-		present_swap_addr = get_offset_addr(d3d9_module,
-				global_hook_info->offsets.d3d9.present_swap);
+		present_addr = get_offset_addr(
+			d3d9_module, global_hook_info->offsets.d3d9.present);
+		present_ex_addr = get_offset_addr(
+			d3d9_module, global_hook_info->offsets.d3d9.present_ex);
+		present_swap_addr = get_offset_addr(
+			d3d9_module,
+			global_hook_info->offsets.d3d9.present_swap);
 	} else {
 		if (!dummy_window) {
 			return false;
 		}
 
-		if (!manually_get_d3d9_addrs(d3d9_module,
-					&present_addr,
-					&present_ex_addr,
-					&present_swap_addr)) {
+		if (!manually_get_d3d9_addrs(d3d9_module, &present_addr,
+					     &present_ex_addr,
+					     &present_swap_addr)) {
 			hlog("Failed to get D3D9 values");
 			return true;
 		}
@@ -919,20 +934,18 @@ bool hook_d3d9(void)
 
 	if (present_swap_addr) {
 		hook_init(&present_swap, present_swap_addr,
-				(void*)hook_present_swap,
-				"IDirect3DSwapChain9::Present");
+			  (void *)hook_present_swap,
+			  "IDirect3DSwapChain9::Present");
 		rehook(&present_swap);
 	}
 	if (present_ex_addr) {
-		hook_init(&present_ex, present_ex_addr,
-				(void*)hook_present_ex,
-				"IDirect3DDevice9Ex::PresentEx");
+		hook_init(&present_ex, present_ex_addr, (void *)hook_present_ex,
+			  "IDirect3DDevice9Ex::PresentEx");
 		rehook(&present_ex);
 	}
 	if (present_addr) {
-		hook_init(&present, present_addr,
-				(void*)hook_present,
-				"IDirect3DDevice9::Present");
+		hook_init(&present, present_addr, (void *)hook_present,
+			  "IDirect3DDevice9::Present");
 		rehook(&present);
 	}
 
